
--[[

A Tabbed Pane with standardd LOTRO tabs. The pane 
area is resized during the Layout() function.

]]--

_G.TabbedPane = class(Turbine.UI.Control);

function TabbedPane:Constructor(window,initialWidth,fixedHeight)
	Turbine.UI.Control.Constructor(self);
	
	-- reference to the containing window for focus grabbing
	self.window = window;
	
	self:SetMouseVisible(false);
	
	self.tabs = {};
	self.selected = 0;
	
	-- thin blue border
	self.border = Turbine.UI.Control();
	self.border:SetParent(self);
	self.border:SetPosition(1,24);
	self.border:SetZOrder(-1);
	self.border:SetMouseVisible(false);
	self.border:SetBackColor(blueBorderColor);
	
	self.initialWidth = initialWidth;
	self.fixedHeight = fixedHeight;
end

function TabbedPane:AddTab(tabName,content)
	local tabIndex = #self.tabs+1;
	
	-- create new tab
	local newTab = Tab(self,tabIndex,tabName,content);
	-- add to tabs table
	table.insert(self.tabs,newTab);
	
	-- if this is the first added tab, select it
	if (tabIndex == 1) then
		self:SelectTab(tabIndex);
	end
end

function TabbedPane:SelectTab(tabIndex)
	if (tabIndex == self.selected) then return end
	
	if (self.selected ~= 0) then
		self.tabs[tabIndex]:SetSelected(false);
	end
	
	self.tabs[tabIndex]:SetSelected(true);
	self.selected = tabIndex;
	
	self:Layout();
end

function TabbedPane:SizeChanged(args)
	self:Layout();
end

function TabbedPane:Layout()
	local w,h = self:GetSize();
	self.border:SetSize(w-5,h-29);
	self.tabs[self.selected].content:SetSize(w-7,h-31);
	self.tabs[self.selected].content:Layout();
end
